==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PasswordImportRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordImportRequestData;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordImportRequest
 */
@JsonPropertyOrder({ PasswordImportRequest.JSON_PROPERTY_DATA, PasswordImportRequest.JSON_PROPERTY_EVENT_TYPE,
        PasswordImportRequest.JSON_PROPERTY_SOURCE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordImportRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DATA = "data";
    private PasswordImportRequestData data;

    public static final String JSON_PROPERTY_EVENT_TYPE = "eventType";
    private String eventType;

    public static final String JSON_PROPERTY_SOURCE = "source";
    private String source;

    public PasswordImportRequest() {
    }

    public PasswordImportRequest data(PasswordImportRequestData data) {

        this.data = data;
        return this;
    }

    /**
     * Get data
     *
     * @return data
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DATA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordImportRequestData getData() {
        return data;
    }

    @JsonProperty(JSON_PROPERTY_DATA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setData(PasswordImportRequestData data) {
        this.data = data;
    }

    public PasswordImportRequest eventType(String eventType) {

        this.eventType = eventType;
        return this;
    }

    /**
     * The type of inline hook. The password import inline hook type is
     * &#x60;com.okta.user.credential.password.import&#x60;.
     *
     * @return eventType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The type of inline hook. The password import inline hook type is `com.okta.user.credential.password.import`.")
    @JsonProperty(JSON_PROPERTY_EVENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventType() {
        return eventType;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventType(String eventType) {
        this.eventType = eventType;
    }

    public PasswordImportRequest source(String source) {

        this.source = source;
        return this;
    }

    /**
     * The ID and URL of the password import inline hook
     *
     * @return source
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The ID and URL of the password import inline hook")
    @JsonProperty(JSON_PROPERTY_SOURCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSource() {
        return source;
    }

    @JsonProperty(JSON_PROPERTY_SOURCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSource(String source) {
        this.source = source;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordImportRequest passwordImportRequest = (PasswordImportRequest) o;
        return Objects.equals(this.data, passwordImportRequest.data)
                && Objects.equals(this.eventType, passwordImportRequest.eventType)
                && Objects.equals(this.source, passwordImportRequest.source);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(data, eventType, source);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordImportRequest {\n");
        sb.append("    data: ").append(toIndentedString(data)).append("\n");
        sb.append("    eventType: ").append(toIndentedString(eventType)).append("\n");
        sb.append("    source: ").append(toIndentedString(source)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/PasswordImportRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordImportRequestData;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordImportRequest
 */
@JsonPropertyOrder({ PasswordImportRequest.JSON_PROPERTY_DATA, PasswordImportRequest.JSON_PROPERTY_EVENT_TYPE,
        PasswordImportRequest.JSON_PROPERTY_SOURCE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PasswordImportRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DATA = "data";
    private PasswordImportRequestData data;

    public static final String JSON_PROPERTY_EVENT_TYPE = "eventType";
    private String eventType;

    public static final String JSON_PROPERTY_SOURCE = "source";
    private String source;

    public PasswordImportRequest() {
    }

    public PasswordImportRequest data(PasswordImportRequestData data) {

        this.data = data;
        return this;
    }

    /**
     * Get data
     *
     * @return data
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DATA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordImportRequestData getData() {
        return data;
    }

    @JsonProperty(JSON_PROPERTY_DATA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setData(PasswordImportRequestData data) {
        this.data = data;
    }

    public PasswordImportRequest eventType(String eventType) {

        this.eventType = eventType;
        return this;
    }

    /**
     * The type of inline hook. The password import inline hook type is
     * &#x60;com.okta.user.credential.password.import&#x60;.
     *
     * @return eventType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The type of inline hook. The password import inline hook type is `com.okta.user.credential.password.import`.")
    @JsonProperty(JSON_PROPERTY_EVENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEventType() {
        return eventType;
    }

    @JsonProperty(JSON_PROPERTY_EVENT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEventType(String eventType) {
        this.eventType = eventType;
    }

    public PasswordImportRequest source(String source) {

        this.source = source;
        return this;
    }

    /**
     * The ID and URL of the password import inline hook
     *
     * @return source
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The ID and URL of the password import inline hook")
    @JsonProperty(JSON_PROPERTY_SOURCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSource() {
        return source;
    }

    @JsonProperty(JSON_PROPERTY_SOURCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSource(String source) {
        this.source = source;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordImportRequest passwordImportRequest = (PasswordImportRequest) o;
        return Objects.equals(this.data, passwordImportRequest.data)
                && Objects.equals(this.eventType, passwordImportRequest.eventType)
                && Objects.equals(this.source, passwordImportRequest.source);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(data, eventType, source);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordImportRequest {\n");
        sb.append("    data: ").append(toIndentedString(data)).append("\n");
        sb.append("    eventType: ").append(toIndentedString(eventType)).append("\n");
        sb.append("    source: ").append(toIndentedString(source)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
